# compara_preco_litro

Description. 
The package compara_preco_litro is used to:
	- 
	-

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install compara_preco_litro

```bash
pip install compara_preco_litro
```

## Author
Pedro_Oliveira

## License
[MIT](https://choosealicense.com/licenses/mit/)